# XGAE: Extreme General Agent Engine 
## XGAE Features
### Functional Features
- Support Custom prompt and external MCP Tools
- Support Langfuse
- Support Langgraph
- Support GAIA2 ARE agent and Custom MCP Apps, Leading over ARE 'default agent'
- Support Human-in-Loop in agent
- Can Use A2A protocol call A2A Agent as tool by 'xgaproxy' project
- Can Use E2B or Daytona Sandbox of 'xgatools' project

### Non-Functional Features
- Faster than SUNA Engine's speed
- Architecture is lighter than SUNA Engine
- Separate tools from Agent Engine


## XGAE Run Mode
### General Agent
- Use General Agent Prompt
- Use general tools mainly
- In addition to using general tools, custom tools can also be used

### Custom Agent
- Use User Custom Prompt
- Use custom tools mainly
- Some general tools can also be used, like 'web_search'


## Examples
- engine: Use XGA Engine in various scenarios, you can find out how to use General or Custom Agent
- langgraph:  Build Reflect mode Langgraph Agent by XGA Engine
- are: Build GAIA2 ARE Agent by XGA Engine
- tools: Simulation tools for example and test